@@ -1,7 +1,7 @@
 package Git::Class::Role::Error;
 
 use Any::Moose '::Role';
-use Carp ();
+use Carp::Clan qw/^(Git::Class|Mouse|Moose)::/;
 
 has '_die_on_error' => (
   is       => 'rw',
@@ -17,15 +17,15 @@ has 'is_verbose' => (
 
 has '_error' => (
   is      => 'rw',
-  isa     => 'Str',
+  isa     => 'Str|Undef',
 #  reader  => '_last_error',  # Mouse doesn't support reader yet
   trigger => sub {
     my ($self, $message) = @_;
-    if ($message ne '') {
+    if (defined $message && $message ne '') {
       chomp $message;
       $self->_die_on_error
-        ? Carp::croak $message
-        : Carp::carp  $message;
+        ? croak $message
+        : carp  $message;
     }
   },
 );
